@@ -11,10 +11,11 @@ import copy
 
 def create_connection_to_mongo(db_name, collection_name, url):
     client = MongoClient(url)
-    local_func = locals()
-    exec(f"connected = client.{db_name}.{collection_name}", globals(), local_func)
-    connected = local_func["connected"]
-    return connected
+    return client['db_name']['collection_name']
+    # local_func = locals()
+    # exec(f"connected = client.{db_name}.{collection_name}", globals(), local_func)
+    # connected = local_func["connected"]
+    # return connected
 
 
 class MongoBaseModel:
@@ -44,4 +45,11 @@ class MongoBaseModel:
         for field in copy.deepcopy(self.data):
             if field not in self.fields:
                 del self.data[field]
+        
+        # kiem tra xem co field nao required ma bi thieu khong
+        for field in self.fields:
+            config = self.fields[field]
+            if config['required'] and field not in self.data:
+                raise Exception(f"field {field} is required!")
+
 
